 #!/bin/bash

set -e
 
dirname="$(dirname $0)"
cfgFile=$dirname/setup.cfg
nginxConfigDir=$dirname/ngnix

while getopts u:p:d:s: option
do
 case "${option}"
 in
 u) db_root_name=${OPTARG};;
 p) db_root_password=${OPTARG};;
 d) domain=${OPTARG};;
 s) skip=$OPTARG;;
 esac
done

if [ -f $cfgFile ]; then
    source $dirname/setup.cfg
fi

echo "						"
echo "┌┬┐┌─┐┌┬┐┌─┐╔═╗┌─┐┌─┐  ┌─┐┌─┐┌┬┐┬ ┬┌─┐";
echo "│││├┤  │ ├─┤╚═╗├┤ │    └─┐├┤  │ │ │├─┘";
echo "┴ ┴└─┘ ┴ ┴ ┴╚═╝└─┘└─┘  └─┘└─┘ ┴ └─┘┴  ";

if [ -z $skip ];then

    echo "Welcome to the metaSec james setup. This setup will help you to install James!"
    echo "Attention! This setup will drop (if excists) and create the james database. Type 'yes' to continue"

    read cont

    if ! [ "$cont" == "yes" ]; then
        echo "setup aborted"
        exit;
    fi
fi

if [ -z $db_root_name ];then
    echo "Please enter your database admin name"
    read db_root_name
fi

if [ -z $db_root_password ];then
    echo "Please enter your database admin password"
    read db_root_password
fi

until mysql -u $db_root_name -p$db_root_password  -e ";" ; do
        read -p "Please enter mysql user: " db_root_name
        read -p "Please enter mysql password: " db_root_password
done

if [ -z $domain ];then
    echo "Please enter your james domainname"
    read domain
fi

if [ -f "/opt/metasec_james/$domain" ]; then
    echo "Domain already excists"
	exit 1;
fi

db_password=$(cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w  16 | head -n 1)
db_user=$(echo "$domain" | cut -d. -f1)
db_name=$db_user

james_user_name="james-adm@$domain"
james_user_password=$(cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 16 | head -n 1)

mysql -u $db_root_name -p$db_root_password -e "DROP DATABASE IF EXISTS $db_name;"
mysql -u $db_root_name -p$db_root_password -e "GRANT USAGE ON *.* TO '$db_user'@'localhost'"
mysql -u $db_root_name -p$db_root_password -e "DROP USER '$db_user'@'localhost';"

mysql -u $db_root_name -p$db_root_password -e "CREATE USER '$db_user'@'localhost' IDENTIFIED BY '$db_password';"
mysql -u $db_root_name -p$db_root_password -e "CREATE DATABASE $db_name"
mysql -u $db_root_name -p$db_root_password -e "GRANT ALL ON $db_name.* to '$db_user'@'localhost';"

mysql -u $db_user -p$db_password $db_name < /usr/share/metasec_core/sampledata/sql/james-structure.sql
mysql -u$db_user -p$db_password $db_name -e "INSERT INTO persons 
	    (pe_login_ok, pe_name, pe_vorname, pe_email, pe_passwd, pe_tz, pe_acl, pe_view_mode, pe_deleted) VALUES 
	    (1,'James','Admin','$james_user_name','$james_user_password','Europe/Berlin','A,AC,ACL,GD','G',0);"

mkdir /opt/metasec_james/$domain
mkdir /opt/metasec_james/$domain/docs
mkdir /opt/metasec_james/$domain/metadata
mkdir /opt/metasec_james/$domain/templates
mkdir /opt/metasec_james/$domain/media
mkdir /opt/metasec_james/$domain/wf_rules

chown -R www-data:www-data /opt/metasec_james/$domain

echo "Setup finished"

exit 0
